/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.object.node.instance;

import org.onosproject.nemo.model.common.NodeId;
import static com.google.common.base.MoreObjects.toStringHelper;

import java.util.Objects;

/**
 * Representation of sub node key.
 */
public class SubNodeKey {
    private final NodeId nodeId;

    /**
     * Creates a sub node key from a given node id.
     *
     * @param nodeId the node id
     */
    public SubNodeKey(NodeId nodeId) {
        this.nodeId = nodeId;
    }

    /**
     * Creates a copy from a given sub node key.
     *
     * @param key the sub node key
     */
    public SubNodeKey(SubNodeKey key) {
        nodeId = key.nodeId;
    }

    /**
     * Returns the node id of this instance.
     *
     * @return node id
     */
    public NodeId getNodeId() {
        return nodeId;
    }

    @Override
    public int hashCode() {
        return nodeId.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        SubNodeKey other = (SubNodeKey) obj;
        return Objects.equals(nodeId, other.nodeId);
    }

    @Override
    public String toString() {
        return toStringHelper(this).add("nodeId", nodeId).toString();
    }
}