/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.common;

import com.google.common.testing.EqualsTester;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

/**
 * Unit tests for {@link OperationId}.
 */
public class OperationIdTest {

    private static final String ID =
            "14ce424a-3e50-4a2a-ad5c-b29845158c8b";
    private static final String OTHER_ID =
            "a4ce424a-3e50-4a2a-ad5c-b29845158c8b";

    private OperationId id;
    private OperationId copy;
    private OperationId diff;

    @Test
    public void fromString() {
        id = new OperationId(ID);
        assertEquals("id not set", ID, id.getValue());
    }

    @Test
    public void copyConstructor() {
        id = new OperationId(ID);
        copy = new OperationId(id);
        new EqualsTester()
                .addEqualityGroup(id, copy)
                .testEquals();
    }

    @Test
    public void equality() {
        id = new OperationId(ID);
        copy = new OperationId(ID);
        diff = new OperationId(OTHER_ID);
        new EqualsTester()
                .addEqualityGroup(id, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}