/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.intent;

import static junit.framework.Assert.assertEquals;

import org.junit.Test;
import org.onosproject.nemo.model.intent.CommonRpcResult.Code;

import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link RegisterUserOutputBuilder}.
 */
public class RegisterUserOutputBuilderTest {

    private static final String MESSAGE = "SomeMessage";
    private static final int OK = 1;
    private static final int ERROR = 0;
    private static final String MESSAGE_ERROR_MSG = "message not set";
    private static final String CODE_ERROR_MSG = "result code not set";
    private static final String AUGMENTATION_ERROR_MSG = "augmentation not equal";

    private Code resultCode;
    private Code otherResultCode;
    private RegisterUserOutput listParam;
    private RegisterUserOutput def;
    private RegisterUserOutput copy;
    private RegisterUserOutput diff;

    @Test
    public void buildRegisterUserOutput() {
        resultCode = Code.forValue(OK);
        listParam = ((RegisterUserOutputBuilder)
                new RegisterUserOutputBuilder()
                .message(MESSAGE)
                .resultCode(resultCode))
                .build();
        def = ((RegisterUserOutputBuilder) new RegisterUserOutputBuilder()
                .message(MESSAGE)
                .resultCode(resultCode))
                .addAugmentation(RegisterUserOutput.class, listParam)
                .build();
        def = new RegisterUserOutputBuilder(def)
                .addAugmentation(RegisterUserOutput.class, null)
                .build();
        assertEquals(MESSAGE_ERROR_MSG, MESSAGE, def.getMessage());
        assertEquals(CODE_ERROR_MSG, resultCode, def.getResultCode());
        assertEquals(AUGMENTATION_ERROR_MSG, listParam, def);
    }

    @Test
    public void fromRegisterUserOutput() {
        resultCode = Code.forValue(OK);
        def = ((RegisterUserOutputBuilder) new RegisterUserOutputBuilder()
                .message(MESSAGE)
                .resultCode(resultCode))
                .build();
        copy = new RegisterUserOutputBuilder(def).build();
        assertEquals(MESSAGE_ERROR_MSG, MESSAGE, copy.getMessage());
        assertEquals(CODE_ERROR_MSG, resultCode, def.getResultCode());
    }

    @Test
    public void equality() {
        resultCode = Code.forValue(OK);
        def = ((RegisterUserOutputBuilder) new RegisterUserOutputBuilder()
                .resultCode(resultCode))
                .build();
        copy = ((RegisterUserOutputBuilder) new RegisterUserOutputBuilder()
                .resultCode(resultCode))
                .build();
        otherResultCode = Code.forValue(ERROR);
        diff = ((RegisterUserOutputBuilder) new RegisterUserOutputBuilder()
                .resultCode(otherResultCode))
                .build();
        new EqualsTester()
                .addEqualityGroup(def, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}