/*
 * Copyright 2016-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.intent.structure.style.nemo.delete.input;

import static org.junit.Assert.assertEquals;

import java.util.ArrayList;
import java.util.List;

import org.junit.Test;
import org.onosproject.nemo.model.common.ConnectionId;
import org.onosproject.nemo.model.common.FlowId;
import org.onosproject.nemo.model.common.NodeId;

import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link ObjectsBuilder}.
 */
public class ObjectsBuilderTest {

    private static final String OBJECTS_ERROR_MSG =
            "objects not set";
    private static final String ID = "00000000-0000-0000-0000-000000000000";
    private static final String OTHER_ID = "00000000-0000-0000-0000-000000000001";

    private List<ConnectionId> connectionIdList;
    private List<ConnectionId> otherConnectionIdList;
    private List<FlowId> flowIdList;
    private List<FlowId> otherFlowIdList;
    private List<NodeId> nodeIdList;
    private List<NodeId> otherNodeIdList;
    private Objects objects;
    private Objects copy;
    private Objects diff;
    private ConnectionId connectionID;
    private ConnectionId otherconnectionID;

    @Test
    public void buildObjectsWithOperationIDlist() {
        connectionIdList = new ArrayList<>();
        flowIdList = new ArrayList<>();
        nodeIdList = new ArrayList<>();
        objects = new ObjectsBuilder()
                .connectionIds(connectionIdList)
                .flowIds(flowIdList).nodeIds(nodeIdList)
                .build();
        assertEquals(OBJECTS_ERROR_MSG, connectionIdList,
                objects.getConnectionIds());
        assertEquals(OBJECTS_ERROR_MSG, flowIdList, objects.getFlowIds());
        assertEquals(OBJECTS_ERROR_MSG, nodeIdList, objects.getNodeIds());
    }

    @Test
    public void fromObjects() {
        connectionIdList = new ArrayList<>();
        flowIdList = new ArrayList<>();
        nodeIdList = new ArrayList<>();
        objects = new ObjectsBuilder()
                .connectionIds(connectionIdList)
                .flowIds(flowIdList).nodeIds(nodeIdList)
                .build();
        copy = new ObjectsBuilder(objects).build();
        assertEquals(OBJECTS_ERROR_MSG, connectionIdList,
                copy.getConnectionIds());
    }

    @Test
    public void equality() {
        connectionIdList = new ArrayList<>();
        flowIdList = new ArrayList<>();
        nodeIdList = new ArrayList<>();
        objects = new ObjectsBuilder()
                .connectionIds(connectionIdList)
                .flowIds(flowIdList).nodeIds(nodeIdList)
                .build();
        otherConnectionIdList = new ArrayList<>();
        otherConnectionIdList.add(null);
        otherFlowIdList = new ArrayList<>();
        otherFlowIdList.add(null);
        otherNodeIdList = new ArrayList<>();
        otherNodeIdList.add(null);
        copy = new ObjectsBuilder().connectionIds(connectionIdList)
                .flowIds(flowIdList).nodeIds(nodeIdList)
                .build();
        diff = new ObjectsBuilder().connectionIds(otherConnectionIdList)
                .flowIds(otherFlowIdList).nodeIds(otherNodeIdList)
                .build();
        new EqualsTester()
                .addEqualityGroup(objects, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }

    @Test
    public void equalityTwo() {
        connectionID = new ConnectionId(ID);
        otherconnectionID = new ConnectionId(OTHER_ID);
        connectionIdList = new ArrayList<>();
        connectionIdList.add(connectionID);
        flowIdList = new ArrayList<>();
        nodeIdList = new ArrayList<>();
        objects = new ObjectsBuilder()
                .connectionIds(connectionIdList)
                .flowIds(flowIdList).nodeIds(nodeIdList)
                .build();
        otherConnectionIdList = new ArrayList<>();
        otherConnectionIdList.add(otherconnectionID);
        copy = new ObjectsBuilder()
                .connectionIds(connectionIdList)
                .flowIds(flowIdList).nodeIds(nodeIdList)
                .build();
        diff = new ObjectsBuilder()
                .connectionIds(otherConnectionIdList)
                .flowIds(flowIdList).nodeIds(nodeIdList)
                .build();
        new EqualsTester()
                .addEqualityGroup(objects, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}